@@ -29,9 +29,9 @@ G_BEGIN_DECLS
 
 typedef struct _ComicsDocument ComicsDocument;
 
-ComicsDocument *comics_document_new       (void);
+GType                 comics_document_get_type (void) G_GNUC_CONST;
 
-GType           comics_document_get_type  (void) G_GNUC_CONST;
+G_MODULE_EXPORT GType register_evince_backend  (GTypeModule *module);
      
 G_END_DECLS
 
